/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 	1番目の要素の値を100で割った値を求める（1番目の要素の値を求めることに注意）
 */
public class DividedBy100 extends Operator {
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{			
		return getCurrentMibValue("var0") / 100.0D;			
	}
}
